<?xml version="1.0"?>
<app>

<category>
Graphics
</category>

<name>
XnView
</name>

<description>
   <am>picture viewer, browser and converter</am>
   <ar>picture viewer, browser and converter</ar>
   <bg>picture viewer, browser and converter</bg>
   <ca>picture viewer, browser and converter</ca>
   <cs>picture viewer, browser and converter</cs>
   <da>billedfremviser, browser og konverter</da>
   <de>Bildbetrachter, -browser und -konverter</de>
   <el>πρόγραμμα προβολής εικόνων, πρόγραμμα περιήγησης και μετατροπέα</el>
   <en>picture viewer, browser and converter</en>
   <es>picture viewer, browser and converter</es>
   <et>picture viewer, browser and converter</et>
   <eu>picture viewer, browser and converter</eu>
   <fa>picture viewer, browser and converter</fa>
   <fi>picture viewer, browser and converter</fi>
   <fr>Visionner, feuilleter et convertir des images</fr>
   <he_IL>picture viewer, browser and converter</he_IL>
   <hi>picture viewer, browser and converter</hi>
   <hr>picture viewer, browser and converter</hr>
   <hu>picture viewer, browser and converter</hu>
   <id>picture viewer, browser and converter</id>
   <is>picture viewer, browser and converter</is>
   <it>visualizzatore e convertitore di immagini</it>
   <ja_JP>picture viewer, browser and converter</ja_JP>
   <ja>picture viewer, browser and converter</ja>
   <kk>picture viewer, browser and converter</kk>
   <ko>picture viewer, browser and converter</ko>
   <lt>picture viewer, browser and converter</lt>
   <mk>picture viewer, browser and converter</mk>
   <nb>picture viewer, browser and converter</nb>
   <nl>afbeelding bekijker, verkenner en omzetter</nl>
   <pl>przeglądarka zdjęć i konwerter</pl>
   <pt_BR>picture viewer, browser and converter</pt_BR>
   <pt>picture viewer, browser and converter</pt>
   <ro>picture viewer, browser and converter</ro>
   <ru>Просмотрщик изображений, каталогизатор и конвертер</ru>
   <sk>picture viewer, browser and converter</sk>
   <sl>picture viewer, browser and converter</sl>
   <sq>picture viewer, browser and converter</sq>
   <sr>picture viewer, browser and converter</sr>
   <sv>bildvisare och konverterare</sv>
   <tr>picture viewer, browser and converter</tr>
   <uk>picture viewer, browser and converter</uk>
   <zh_CN>picture viewer, browser and converter</zh_CN>
   <zh_TW>picture viewer, browser and converter</zh_TW>
</description>

<installable>
32
</installable>

<screenshot>https://linux-cdn.softpedia.com/screenshots/XnView-MP_2.jpeg</screenshot>

<preinstall>
wget https://download.xnview.com/XnViewMP-linux.deb
dpkg -i XnViewMP-linux.deb
rm XnViewMP-linux.deb
</preinstall>

<install_package_names>
xnview
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
xnview
</uninstall_package_names>
</app>
